@@ -35,10 +35,10 @@ class BasicResult:
         return self.timestamp
 
     def get_timestamp_as_utc(self):
-        return datetime.utcfromtimestamp(self.timestamp/1000.0)
+        return datetime.utcfromtimestamp(self.timestamp / 1000.0)
 
     def __repr__(self):
-        return "%s-%s-%d" % (self.symbol, self.instrument_id, self.timestamp)
+        return "symbol:%s,instrument_id:%s,timestamp:%d" % (self.symbol, self.instrument_id, self.timestamp)
 
     def __str__(self):
         return self.__repr__()
