@@ -16,6 +16,6 @@
 # under the License.
 
 # coding=utf-8
-
-PAYLOAD_TYPE_BASIC_QUOTE = 0
+PAYLOAD_TYPE_QUOTE = 0
 PAYLOAD_TYPE_SHAPSHOT = 1
+PAYLOAD_TYPE_TICK = 2
\ No newline at end of file
